yakumo.base

Package yakumo :: Module base |
[hide private]
[frames] | no frames]

# Module base

source code

Abstract classes for resource management

Classes | [hide private]
| Resource Base class for resources.
| Manager Base class for resource managers.
| SubManager Base class for sub resource managers.
| GlanceV2Resource Base class for resource managers which don't use _json_resource_key.
| GlanceV2Manager Base class for resource managers which don't use _json_resource_key.
| GlanceV2SubManager Base class for sub resource managers for GlanceV2Manager.

Variables | [hide private]
| WRAPPER_METHODS = ``[``]``
| BAD_ATTRS = ``[``'``self``'``]``
| __package__ = ``'``yakumo``'``